@@ -59,7 +59,7 @@ pub struct CorePlugin;
 
 #[allow(deprecated)]
 impl Plugin for CorePlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.init_resource::<Gravity>()
             .init_resource::<PhysicsTime>()
             .init_resource::<PhysicsSteps>()
@@ -134,13 +134,13 @@ impl core::fmt::Debug for CustomCollisionShape {
 /// ```
 /// # use bevy::prelude::*;
 /// # use heron_core::*;
-/// fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
+/// fn spawn(mut commands: Commands) {
 ///     commands.spawn_bundle(todo!("Spawn your sprite/mesh, incl. at least a GlobalTransform"))
 ///         .insert(RigidBody::Dynamic) // Create a dynamic rigid body
 ///         .insert(CollisionShape::Sphere { radius: 1.0 }); // Attach a collision shape
 /// }
 /// ```
-#[derive(Debug, Clone, Reflect)]
+#[derive(Debug, Clone, Component, Reflect)]
 #[non_exhaustive]
 pub enum CollisionShape {
     /// A sphere (or circle in 2d) shape defined by its radius
@@ -247,13 +247,13 @@ impl Default for CollisionShape {
 /// ```
 /// # use bevy::prelude::*;
 /// # use heron_core::*;
-/// fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
+/// fn spawn(mut commands: Commands) {
 ///     commands.spawn_bundle(todo!("Spawn your sprite/mesh, incl. at least a GlobalTransform"))
 ///         .insert(RigidBody::Dynamic) // Create a dynamic rigid body
 ///         .insert(CollisionShape::Sphere { radius: 1.0 }); // Attach a collision shape
 /// }
 /// ```
-#[derive(Debug, Copy, Clone, Eq, PartialEq, Reflect)]
+#[derive(Debug, Component, Copy, Clone, Eq, PartialEq, Reflect)]
 pub enum RigidBody {
     /// A dynamic body is normally affected by physic forces and affect the other bodies normally too.
     ///
@@ -326,7 +326,7 @@ impl RigidBody {
 /// ```rust
 /// # use heron_core::*;
 /// # use bevy::prelude::*;
-/// fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
+/// fn spawn(mut commands: Commands) {
 ///   commands.spawn_bundle(todo!("Spawn your sprite/mesh, incl. at least a GlobalTransform"))
 ///     .insert(RigidBody::Dynamic) // <-- A non-sensor rigid body
 ///     .with_children(|children| {
@@ -345,7 +345,7 @@ impl RigidBody {
 ///     });
 /// }
 /// ```
-#[derive(Debug, Copy, Clone, Default, Reflect)]
+#[derive(Debug, Component, Copy, Clone, Default, Reflect)]
 pub struct SensorShape;
 
 /// Component that defines the physics properties of the rigid body
@@ -357,7 +357,7 @@ pub struct SensorShape;
 /// ```
 /// # use bevy::prelude::*;
 /// # use heron_core::*;
-/// fn spawn(mut commands: Commands, mut materials: ResMut<Assets<ColorMaterial>>) {
+/// fn spawn(mut commands: Commands) {
 ///     commands.spawn_bundle(todo!("Spawn your sprite/mesh, incl. at least a GlobalTransform"))
 ///         .insert(CollisionShape::Sphere { radius: 1.0 }) // Make a body (is dynamic by default)
 ///         .insert(PhysicMaterial {
@@ -367,7 +367,7 @@ pub struct SensorShape;
 ///         });
 /// }
 /// ```
-#[derive(Debug, Copy, Clone, PartialEq, Reflect)]
+#[derive(Debug, Component, Copy, Clone, PartialEq, Reflect)]
 pub struct PhysicMaterial {
     /// Coefficient of restitution. Affect how much it "bounces" when colliding with other objects.
     ///
